// -*- C++ -*-
#include "Rivet/Analysis.hh"
#include "Rivet/Projections/ChargedFinalState.hh"
#include "Rivet/Projections/FinalState.hh"

namespace Rivet {

  using namespace Cuts;

  class CMS_2015_I1384119 : public Analysis {
  public:

    /// Constructor
    CMS_2015_I1384119()
      : Analysis("CMS_2015_I1384119")
    {    }

    /// Book histograms and initialise projections before the run
    void init() {
      const FinalState fsa(-20.0, 20.0, 0.0 * GeV);
      addProjection(fsa, "FSA");
      const ChargedFinalState cfs(-2.0, 2.0, 0.0 * GeV);
      addProjection(cfs, "CFS");

      _hist_dNch_dEta_inel = bookHisto1D(1, 1, 1);
    }


    /// Perform the per-event analysis
    void analyze(const Event& event) {
      const FinalState& fsa = applyProjection<FinalState>(event, "FSA");
      // apply inelastic selection (veto pp -> pp eleastic events)
      if (fsa.size() <= 2) vetoEvent;

      const ChargedFinalState& cfs = applyProjection<ChargedFinalState>(event, "CFS");

      const double weight = event.weight();

      foreach (const Particle& p, cfs.particles()) {
        int id = p.pid();
        // continue if particle is a proton, a kaon or a pion
        if (( (abs(id) == 211) || (abs(id) == 321) || (abs(id) == 2212)))  {
          _hist_dNch_dEta_inel->fill(p.eta(), weight);
        }
      }
    }


    /// Normalise histograms etc., after the run
    void finalize() {
      scale(_hist_dNch_dEta_inel,  1. / sumOfWeights());
    }


  private:

    /// Histograms
    Histo1DPtr _hist_dNch_dEta_inel;

  };


  // The hook for the plugin system
  DECLARE_RIVET_PLUGIN(CMS_2015_I1384119);

}
